import java.io.*;
import java.util.Scanner;
import java.util.List;
/**
 *   ConsoleUI is a text-based user interface for the PhoneMapper 
 *   application.  All input/output with the user occurs here.
 *   No actual data manipulation happens here.
**/

public class ConsoleUI
{
    private Scanner console;
    private PrintWriter display;
    private PhoneMap phonemap;
    /**
     * Constructs the console view of the application. 
     * @param rdr a Reader from which to read the user's input,
     * usually <code>System.in</code>
     * @param wtr a Writer to which to display the output, 
     * usually <code>System.out</code>
     */
    public ConsoleUI(Reader rdr, Writer wtr) throws IOException
    {
        console = new Scanner(rdr);
        display = new PrintWriter(wtr, true);   
        phonemap = new PhoneMap();
    }

    /** Run the console user interface, obtaining words from the specified
     *  Reader, and displaying results on the specified Writer.
     */
    public void run()
    {
        // Read all the words from the input, translating each
        // and adding it to the map.
        while (console.hasNextLine())
        {
            String line = console.nextLine();
            String word = line.trim().toLowerCase();
            String acctNum = phonemap.translate(word);
            int count = phonemap.addNumber(acctNum, word);
            phonemap.updateHighCount(acctNum, count);
        }
        // output the winners :
        List<String> winners = phonemap.getResults();
        // FOR each winner LOOP
        for (String acctNum : winners)
        {
            // Show winning acct number
            display.print(acctNum + " ");
            //     get the words for that acctNum
            List<String> words = phonemap.getWordsForAcct(acctNum);
            //     FOR each word LOOP
            for (String word : words)
            {
                //        print the word
                display.print(word + " ");
            }
            display.println();
            //     END LOOP
        }
        // END LOOP
        
    }


}